==> jc-1.4.0.tar.gz: java/awt/font/TransformAttribute.h <==
// public final class java.awt.font.TransformAttribute

// class file dependencies
// @dep_class cce0309600d8c144 java_awt_font_TransformAttribute
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_TransformAttribute_H_
#define _JC_java_awt_font_TransformAttribute_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_TransformAttribute$sub_refs	_jc_java_awt_font_TransformAttribute$sub_refs;
typedef struct _jc_java_awt_font_TransformAttribute$sub_nonrefs	_jc_java_awt_font_TransformAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_TransformAttribute$refs	_jc_java_awt_font_TransformAttribute$refs;
typedef struct _jc_java_awt_font_TransformAttribute$nonrefs	_jc_java_awt_font_TransformAttribute$nonrefs;
typedef struct _jc_java_awt_font_TransformAttribute$object	_jc_java_awt_font_TransformAttribute$object;

typedef struct _jc_java_awt_font_TransformAttribute$fields_struct	_jc_java_awt_font_TransformAttribute$fields_struct;
typedef const struct _jc_java_awt_font_TransformAttribute$vmethods	_jc_java_awt_font_TransformAttribute$vmethods;
typedef const struct _jc_java_awt_font_TransformAttribute$vtable	_jc_java_awt_font_TransformAttribute$vtable;
typedef const struct _jc_java_awt_font_TransformAttribute$vtype	_jc_java_awt_font_TransformAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_TransformAttribute$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_font_TransformAttribute$fields_struct _jc_java_awt_font_TransformAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_TransformAttribute$method$_init$27279b2b7f9265b3(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *, struct _jc_java_awt_geom_AffineTransform$object *);

// Virtual methods
extern struct _jc_java_awt_geom_AffineTransform$object *_jc_java_awt_font_TransformAttribute$method$getTransform$c5fe408eec532e13(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *);
extern jboolean _jc_java_awt_font_TransformAttribute$method$isIdentity$b17ecbcbcedf774c(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TransformAttribute$method_info$getTransform$c5fe408eec532e13;
extern _jc_method _jc_java_awt_font_TransformAttribute$method_info$isIdentity$b17ecbcbcedf774c;

// Virtual methods structure
struct _jc_java_awt_font_TransformAttribute$vmethods {
	struct _jc_java_awt_geom_AffineTransform$object	*(*getTransform$c5fe408eec532e13)(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *);
	jboolean	(*isIdentity$b17ecbcbcedf774c)(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *);
};

// Vtable
struct _jc_java_awt_font_TransformAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_TransformAttribute$vmethods	java_awt_font_TransformAttribute;
};

// Vtype
struct _jc_java_awt_font_TransformAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_TransformAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TransformAttribute$sub_refs {
	struct _jc_java_awt_geom_AffineTransform$object	*affineTransform;
};

// Reference instance fields (object)
struct _jc_java_awt_font_TransformAttribute$refs {
    _jc_java_awt_font_TransformAttribute$sub_refs	java_awt_font_TransformAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TransformAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TransformAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_TransformAttribute$sub_nonrefs	java_awt_font_TransformAttribute;
};

// Object instance structure
struct _jc_java_awt_font_TransformAttribute$object {
	_jc_java_awt_font_TransformAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TransformAttribute$vtype	*vtype;
	_jc_java_awt_font_TransformAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TransformAttribute$vtype _jc_java_awt_font_TransformAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TransformAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TransformAttribute$class_object;

#endif	/* _JC_java_awt_font_TransformAttribute_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/TransformAttribute.h <==
// public final class java.awt.font.TransformAttribute

// class file dependencies
// @dep_class cce0309600d8c144 java_awt_font_TransformAttribute
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_TransformAttribute_H_
#define _JC_java_awt_font_TransformAttribute_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_TransformAttribute$sub_refs	_jc_java_awt_font_TransformAttribute$sub_refs;
typedef struct _jc_java_awt_font_TransformAttribute$sub_nonrefs	_jc_java_awt_font_TransformAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_TransformAttribute$refs	_jc_java_awt_font_TransformAttribute$refs;
typedef struct _jc_java_awt_font_TransformAttribute$nonrefs	_jc_java_awt_font_TransformAttribute$nonrefs;
typedef struct _jc_java_awt_font_TransformAttribute$object	_jc_java_awt_font_TransformAttribute$object;

typedef struct _jc_java_awt_font_TransformAttribute$fields_struct	_jc_java_awt_font_TransformAttribute$fields_struct;
typedef const struct _jc_java_awt_font_TransformAttribute$vmethods	_jc_java_awt_font_TransformAttribute$vmethods;
typedef const struct _jc_java_awt_font_TransformAttribute$vtable	_jc_java_awt_font_TransformAttribute$vtable;
typedef const struct _jc_java_awt_font_TransformAttribute$vtype	_jc_java_awt_font_TransformAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_TransformAttribute$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_font_TransformAttribute$fields_struct _jc_java_awt_font_TransformAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_TransformAttribute$method$_init$27279b2b7f9265b3(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_geom_AffineTransform$object *_jc_java_awt_font_TransformAttribute$method$getTransform$c5fe408eec532e13(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_font_TransformAttribute$method$isIdentity$b17ecbcbcedf774c(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TransformAttribute$method_info$getTransform$c5fe408eec532e13;
extern _jc_method _jc_java_awt_font_TransformAttribute$method_info$isIdentity$b17ecbcbcedf774c;

// Virtual methods structure
struct _jc_java_awt_font_TransformAttribute$vmethods {
	struct _jc_java_awt_geom_AffineTransform$object	*(*getTransform$c5fe408eec532e13)(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *) _JC_JCNI_ATTR;
	jboolean	(*isIdentity$b17ecbcbcedf774c)(_jc_env *, struct _jc_java_awt_font_TransformAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_TransformAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_TransformAttribute$vmethods	java_awt_font_TransformAttribute;
};

// Vtype
struct _jc_java_awt_font_TransformAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_TransformAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TransformAttribute$sub_refs {
	struct _jc_java_awt_geom_AffineTransform$object	*affineTransform;
};

// Reference instance fields (object)
struct _jc_java_awt_font_TransformAttribute$refs {
    _jc_java_awt_font_TransformAttribute$sub_refs	java_awt_font_TransformAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TransformAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TransformAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_TransformAttribute$sub_nonrefs	java_awt_font_TransformAttribute;
};

// Object instance structure
struct _jc_java_awt_font_TransformAttribute$object {
	_jc_java_awt_font_TransformAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TransformAttribute$vtype	*vtype;
	_jc_java_awt_font_TransformAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TransformAttribute$vtype _jc_java_awt_font_TransformAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TransformAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TransformAttribute$class_object;

#endif	/* _JC_java_awt_font_TransformAttribute_H_ */
